MockMockMock is a Python `mocking <http://en.wikipedia.org/wiki/Mock_object>`_ library.

It focuses on very explicit definition of the mocks' behaviour.
It allows as-specific-as-needed unit-tests as well as more generic ones.

Documentation
=============

See http://jacquev6.github.com/MockMockMock
